@@ -3,6 +3,4 @@ from .extension import load_jupyter_server_extension  # noqa: F401
 
 
 def _jupyter_server_extension_paths():
-    return [{
-        "module": "jupyterlab_autoversion.extension"
-    }]
+    return [{"module": "jupyterlab_autoversion.extension"}]
